@@ -1,5 +1,7 @@
 import os, signal, threading, sys
 from delphai_utils.logging import logging
+import asyncio
+from functools import partial, wraps
 
 
 # Disable
@@ -23,6 +25,17 @@ def wait_for_exit():
   forever.wait()
 
 
+def async_wrap(func):
+  @wraps(func)
+  async def run(*args, loop=None, executor=None, **kwargs):
+    if loop is None:
+      loop = asyncio.get_event_loop()
+    pfunc = partial(func, *args, **kwargs)
+    return await loop.run_in_executor(executor, pfunc)
+
+  return run
+
+
 def generate_default_message(message_descriptor, lvls: int = 10):
   """
   Returns descriptive template for message.
